@@ -1,31 +1,29 @@
 #' Return the middle x percent of values
-#' 
+#'
 #' @param x numeric vector
 #' @param middle percentage you want to center around
 #' @param within percentage around center
 #' @return logical vector
 #' @export
-#' 
+#'
 #' @examples
 #' x <- runif(20)
 #' near_middle(x = x,
 #'             middle = 0.5,
 #'             within = 0.2)
-#'             
+#'
 #' library(dplyr)
 #' heights %>% features(height_cm, list(min = min)) %>%
 #'   filter(near_middle(min, 0.5, 0.1))
-#'             
-near_middle <- function(x,
-                        middle,
-                        within){
-  
+#'
+near_middle <- function(x, middle, within) {
   within <- within / 2
-  
-  dplyr::between(dplyr::percent_rank(x),
-                 left = middle - within,
-                 right = middle + within)
-  
+
+  dplyr::between(
+    dplyr::percent_rank(x),
+    left = middle - within,
+    right = middle + within
+  )
 }
 
 #' Return x percent to y percent of values
@@ -39,54 +37,50 @@ near_middle <- function(x,
 #'
 #' @examples
 #' x <- runif(20)
-#' 
+#'
 #' near_middle(x = x,
 #'             middle = 0.5,
 #'             within = 0.2)
-#' 
+#'
 #' library(dplyr)
 #' heights %>% features(height_cm, list(min = min)) %>%
 #'   filter(near_between(min, 0.1, 0.9))
 #'
 #' near_quantile(x = x,
-#'               probs = 0.5, 
+#'               probs = 0.5,
 #'               tol = 0.01)
-#' 
+#'
 #' near_quantile(x, c(0.25, 0.5, 0.75), 0.05)
-#' 
+#'
 #' heights %>%
 #'   features(height_cm, l_five_num) %>%
 #'   mutate_at(vars(min:max),
 #'             .funs = near_quantile,
-#'             0.5, 
+#'             0.5,
 #'             0.01) %>%
 #'   filter(min)
-#' 
+#'
 #' heights %>%
 #'   features(height_cm, list(min = min)) %>%
 #'   mutate(min_near_q3 = near_quantile(min, c(0.25, 0.5, 0.75), 0.01)) %>%
 #'   filter(min_near_q3)
-#' 
+#'
 #' heights %>%
 #'   features(height_cm, list(min = min)) %>%
 #'   filter(near_between(min, 0.1, 0.9))
-#' 
+#'
 #' heights %>%
 #'   features(height_cm, list(min = min)) %>%
 #'   filter(near_middle(min, 0.5, 0.1))
-near_between <- function(x,
-                         from,
-                         to){
-  dplyr::between(dplyr::percent_rank(x),
-                 left = from,
-                 right = to)
+near_between <- function(x, from, to) {
+  dplyr::between(dplyr::percent_rank(x), left = from, right = to)
 }
 
 #' Which values are nearest to any given quantiles
 #'
 #' @param x vector
 #' @param probs quantiles to calculate
-#' @param tol tolerance in terms of x that you will accept near to the 
+#' @param tol tolerance in terms of x that you will accept near to the
 #'   quantile. Default is 0.01.
 #'
 #' @return logical vector of TRUE/FALSE if number is close to a quantile
@@ -94,87 +88,85 @@ near_between <- function(x,
 #' x <- runif(20)
 #' near_quantile(x, 0.5, 0.05)
 #' near_quantile(x, c(0.25, 0.5, 0.75), 0.05)
-#' 
+#'
 #' library(dplyr)
-#' heights %>% 
-#'   features(height_cm, list(min = min)) %>% 
+#' heights %>%
+#'   features(height_cm, list(min = min)) %>%
 #'   mutate(min_near_median = near_quantile(min, 0.5, 0.01)) %>%
 #'   filter(min_near_median)
-#' heights %>% 
-#'   features(height_cm, list(min = min)) %>% 
+#' heights %>%
+#'   features(height_cm, list(min = min)) %>%
 #'   mutate(min_near_q3 = near_quantile(min, c(0.25, 0.5, 0.75), 0.01)) %>%
 #'   filter(min_near_q3)
 #' @export
 
-near_quantile <- function(x, probs, tol = 0.01){
+near_quantile <- function(x, probs, tol = 0.01) {
   x <- as.numeric(x)
-  
+
   quant <- qtl(x, probs = probs)
   upper <- purrr::map_dbl(quant, sum, tol)
   lower <- purrr::map_dbl(quant, sum, -tol)
-  
+
   part_btn <- purrr::partial(dplyr::between, x = x)
 
-  purrr::map2_dfr(.x = lower,
-                  .y = upper,
-                  .f = part_btn) %>%
-    rowSums() == 1
-  
+  purrr::map2_dfr(.x = lower, .y = upper, .f = part_btn) %>%
+    rowSums() ==
+    1
 }
 
 
 #' Is x nearest to y?
-#' 
-#' @description  Returns TRUE if x is nearest to y. 
+#'
+#' @description  Returns TRUE if x is nearest to y.
 #'     There are two implementations. `nearest_lgl()` returns a logical vector
 #'     when an element of the first argument is nearest to an element of the
-#'     second argument. `nearest_qt_lgl()` is similar to `nearest_lgl()`, but 
+#'     second argument. `nearest_qt_lgl()` is similar to `nearest_lgl()`, but
 #'     instead determines if an element of the first argument is nearest to
-#'     some value of the given quantile probabilities. See example for more 
+#'     some value of the given quantile probabilities. See example for more
 #'     detail.
 #'
 #' @param x a numeric vector
 #' @param y a numeric vector
 #' @param ... (if used) arguments to pass to `quantile()`.
 #'
-#' @return logical vector of `length(y)` 
+#' @return logical vector of `length(y)`
 #' @name nearests
 #' @export
 #'
 #' @examples
-#' 
+#'
 #' x <- 1:10
 #' y <- 5:14
 #' z <- 16:25
 #' a <- -1:-5
 #' b <- -1
-#' 
+#'
 #' nearest_lgl(x, y)
 #' nearest_lgl(y, x)
-#' 
+#'
 #' nearest_lgl(x, z)
 #' nearest_lgl(z, x)
-#' 
+#'
 #' nearest_lgl(x, a)
 #' nearest_lgl(a, x)
-#' 
+#'
 #' nearest_lgl(x, b)
 #' nearest_lgl(b, x)
-#' 
+#'
 #' library(dplyr)
 #' heights_near_min <- heights %>%
 #'   filter(nearest_lgl(min(height_cm), height_cm))
-#'   
+#'
 #' heights_near_fivenum <- heights %>%
 #'   filter(nearest_lgl(fivenum(height_cm), height_cm))
-#'   
+#'
 #' heights_near_qt_1 <- heights %>%
 #'   filter(nearest_qt_lgl(height_cm, c(0.5)))
-#'   
+#'
 #' heights_near_qt_3 <- heights %>%
 #'   filter(nearest_qt_lgl(height_cm, c(0.1, 0.5, 0.9)))
-#' 
-nearest_lgl <- function(x, y){
+#'
+nearest_lgl <- function(x, y) {
   x <- vctrs::vec_cast(x, to = double())
   y <- vctrs::vec_cast(y, to = double())
   out <- logical(length(y))
@@ -184,7 +176,7 @@ nearest_lgl <- function(x, y){
 
 #' @export
 #' @rdname nearests
-nearest_qt_lgl <- function(y, ...){
+nearest_qt_lgl <- function(y, ...) {
   x <- stats::quantile(y, ...)
   out <- logical(length(y))
   out[purrr::map_dbl(x, function(x) which.min(abs(y - x)))] <- TRUE
@@ -199,30 +191,30 @@ nearest_qt_lgl <- function(y, ...){
 #   out[purrr::map_dbl(x, function(x) which.min(abs(y - x)))] <- TRUE
 #   out
 # }
-# 
-# 
-# # Mitch's notes 
+#
+#
+# # Mitch's notes
 # stat_near_quant(min, 0.5, 0.1)(map(seq_len(100), rnorm))
-# 
-# 
+#
+#
 # min_near_quant <- stat_near_quant(min, 0.5, 0.1)
-# 
+#
 # min_near_quant(rnorm(1000))
-# 
+#
 # stat_near_quant <- function(fn, qt, tol){
 #   function(lst, ...){
 #     # ??? magic quantile stuff ???
 #     fn_out <- map_dbl(lst, fn, ...)
-#     
+#
 #     quantile(fn_out, probs = qt)
-#     # 
+#     #
 #     # x_near <- map(qt_out, ~ x[dplyr::near(x, .x, tol)])
-#     # 
+#     #
 #     # map(x_near, fn, ...)
 #   }
 # }
-# 
+#
 # ?dplyr::ntile()
-# 
+#
 # # does it return a lgl (is it near to a quantile? TRUE/FALSE)
 # # or a character? (q25, or q50, say - or NA if not near)
