@@ -2,18 +2,15 @@ wages_monotonic <- wages %>%
   features(ln_wages, feat_monotonic)
 
 test_that("feat_monotonic returns the right names", {
-  expect_equal(names(wages_monotonic),
-               c("id",
-                 "increase",
-                 "decrease",
-                 "unvary",
-                 "monotonic"))
+  expect_equal(
+    names(wages_monotonic),
+    c("id", "increase", "decrease", "unvary", "monotonic")
+  )
 })
 
 
 test_that("feat_monotonic returns the right dimensions", {
-  expect_equal(dim(wages_monotonic),
-               c(888, 5))
+  expect_equal(dim(wages_monotonic), c(888, 5))
 })
 
 library(dplyr)
